# fractal-converters-tools

[![License](https://img.shields.io/pypi/l/fractal-converters-tools.svg?color=green)](https://github.com/fractal-analytics-platform/fractal-converters-tools/raw/main/LICENSE)
[![PyPI](https://img.shields.io/pypi/v/fractal-converters-tools.svg?color=green)](https://pypi.org/project/fractal-converters-tools)
[![Python Version](https://img.shields.io/pypi/pyversions/fractal-converters-tools.svg?color=green)](https://python.org)
[![CI](https://github.com/fractal-analytics-platform/fractal-converters-tools/actions/workflows/ci.yml/badge.svg)](https://github.com/fractal-analytics-platform/fractal-converters-tools/actions/workflows/ci.yml)
[![codecov](https://codecov.io/gh/fractal-analytics-platform/fractal-converters-tools/branch/main/graph/badge.svg)](https://codecov.io/gh/fractal-analytics-platform/fractal-converters-tools)


Tooling to build ome-zarr HCS plate converters
